@@ -14,11 +14,22 @@
 #' @export
 parsnip::multi_predict
 
+#' @importFrom generics tidy
+#' @export
+generics::tidy
+
+#' @importFrom generics tunable
+#' @export
+generics::tunable
+
 # ------------------------------------------------------------------------------
 
 utils::globalVariables(
   c(
     ".pred_1", ".pred_2", ".pred_class", ".row_number", "object", "new_data", "name",
-    ".pred", "(Intercept)", "committee", "rule", "trials"
+    ".pred", "(Intercept)", "committee", "rule", "trials",
+    "column", "conds", "cover", "coverage", "error", "esterr", "estimate", "feature", "hival",
+    "less_than", "level", "loval", "num_conditions", "rule_comp", "rule_id", "rule_num",
+    "split_id", "split_value", "statistic", "term", "value"
   )
 )
