@@ -74,7 +74,7 @@
 #' @return An updated `parsnip` model specification.
 #' @seealso [parsnip::fit()], [parsnip::fit_xy()], [xrf::xrf.formula()]
 #' @references Friedman, J. H., and Popescu, B. E. (2008). "Predictive learning
-#' via rule ensembles." _The Annals ofApplied Statistics_, 2(3), 916-954.
+#' via rule ensembles." _The Annals of Applied Statistics_, 2(3), 916-954.
 #' @examples
 #' rule_fit()
 #' # Parameters can be represented by a placeholder:
@@ -241,6 +241,7 @@ xrf_fit <-
     res <- rlang::eval_tidy(cl)
     res$lambda  <- lambda
     res$family <- args$family
+    res$levels <- get_levels(formula, data)
     res
   }
 
@@ -285,6 +286,17 @@ get_glmnet_type <- function(x, type) {
 }
 
 
+get_levels <- function(formula, data) {
+  m <- model.frame(formula, head(data))
+  y <- model.response(m)
+  res <- levels(y)
+  if (length(res) == 0) {
+    res <- character(0)
+  }
+  res
+}
+
+
 #' @export
 #' @keywords internal
 #' @rdname rules-internal
@@ -501,10 +513,10 @@ tunable.rule_fit <- function(x, ...) {
              'loss_reduction', 'sample_size', 'penalty'),
     call_info = list(
       list(pkg = "rules", fun = "mtry_prop"),
-      list(pkg = "dials", fun = "trees", range = c(5, 100)),
+      list(pkg = "dials", fun = "trees", range = c(5L, 100L)),
       list(pkg = "dials", fun = "min_n"),
-      list(pkg = "dials", fun = "tree_depth", range = c(1, 10)),
-      list(pkg = "dials", fun = "learn_rate"),
+      list(pkg = "dials", fun = "tree_depth", range = c(1L, 10L)),
+      list(pkg = "dials", fun = "learn_rate", range = c(-10, 0)),
       list(pkg = "dials", fun = "loss_reduction"),
       list(pkg = "dials", fun = "sample_prop", range = c(0.50, 0.95)),
       list(pkg = "dials", fun = "penalty")
