@@ -8,6 +8,8 @@ lvls <- levels(ad_mod$Class)
 # ------------------------------------------------------------------------------
 
 test_that('formula method', {
+  skip_on_cran()
+  skip_if_not_installed("xrf")
 
   set.seed(4526)
   rf_fit_exp <-
@@ -88,6 +90,8 @@ test_that('formula method', {
 # ------------------------------------------------------------------------------
 
 test_that('non-formula method', {
+  skip_on_cran()
+  skip_if_not_installed("xrf")
 
   set.seed(4526)
   rf_fit_exp <-
@@ -164,3 +168,77 @@ test_that('non-formula method', {
   }
 
 })
+
+# ------------------------------------------------------------------------------
+
+test_that('tidy method - two classes', {
+  skip_on_cran()
+  skip_if_not_installed("xrf")
+
+  library(xrf)
+
+  xrf_cls_mod <-
+    rule_fit(trees = 3, penalty = .001) %>%
+    set_engine("xrf") %>%
+    set_mode("classification")
+
+  set.seed(1)
+  xrf_cls_fit <-
+    xrf_cls_mod %>%
+    fit(Class ~ ., data = ad_mod)
+  xrf_rule_res <- tidy(xrf_cls_fit)
+  raw_coef <- coef(xrf_cls_fit$fit, lambda = 0.001)
+  raw_coef <- raw_coef[raw_coef[,1] != 0, ]
+  expect_true(nrow(raw_coef) == nrow(xrf_rule_res))
+  expect_true(all(raw_coef$term %in% xrf_rule_res$rule_id))
+
+  xrf_col_res <- tidy(xrf_cls_fit, unit = "column")
+  expect_equal(
+    sort(unique(xrf_col_res$term)),
+    c("(Intercept)", "Genotype", "MMP10", "p_tau")
+  )
+  expect_equal(
+    sort(unique(raw_coef$term)),
+    sort(unique(xrf_col_res$rule_id))
+  )
+})
+
+
+test_that('tunable', {
+  rule_fit_xrf <-
+    rules::rule_fit(
+      tree_depth = tune(),
+      trees = tune(),
+      learn_rate = tune(),
+      mtry = tune(),
+      min_n = tune(),
+      loss_reduction = tune(),
+      sample_size = tune(),
+      penalty = tune()
+    ) %>%
+    set_engine('xrf') %>%
+    set_mode('classification') %>%
+    tunable()
+
+  expect_equal(
+    rule_fit_xrf$call_info[rule_fit_xrf$name=="trees"][[1]]$range,
+    c(5L, 100L)
+  )
+
+  expect_equal(
+    rule_fit_xrf$call_info[rule_fit_xrf$name=="tree_depth"][[1]]$range,
+    c(1L, 10L)
+  )
+
+  expect_equal(
+    rule_fit_xrf$call_info[rule_fit_xrf$name=="learn_rate"][[1]]$range,
+    c(-10, 0)
+  )
+
+  expect_equal(
+    rule_fit_xrf$call_info[rule_fit_xrf$name=="sample_size"][[1]]$range,
+    c(0.50, 0.95)
+  )
+
+})
+
